staging.Local — staging class for running local jobs — GromacsWrapper 0.5.0-dev documentation

# `staging.Local` — staging class for running local jobs

Ersatz framework for running a staged script without actually doing any staging.

Simply replace

    from staging.SunGridEngine import Job

with

    from staging.Local import Job

in the python run script (see `staging.SunGridEngine` for an example script).

## Description of the `Job` class

class `staging.Local.` `Job`(*args, **kwargs)

  Job class that doesn’t do anything but provides parameters as the ‘real’ classes do.

  job = Job(inputfiles=<dict>,outputfiles=<dict>,variables=<dict>,startdir=<PWD>)

  `save`(filename)

    Save the Job() as a pickled file.

    Restore with

    > import staging.SunGridengine import cPickle job = cPickle.load(open(<filename>,’r’))